@@ -30,14 +30,17 @@ test_format("acs_article")
 test_format("aea_article")
 test_format("ams_article")
 test_format("asa_article")
+test_format("biometrics_article")
 test_format("elsevier_article")
 test_format("jss_article")
 test_format("rss_article")
 test_format("pnas_article")
 test_format("ieee_article")
 test_format("rjournal_article")
+test_format("sage_article")
 test_format("sim_article")
 test_format("peerj_article")
 test_format("amq_article")
 test_format("mdpi_article")
 test_format("mnras_article")
+test_format("copernicus_article")
